==> element-plus-2.1.0.jar: META-INF/resources/webjars/element-plus/2.1.0/lib/components/empty/src/img-empty.js <==
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vue = require('vue');
var pluginVue_exportHelper = require('../../../_virtual/plugin-vue_export-helper.js');

let id = 0;
const _sfc_main = vue.defineComponent({
  name: "ImgEmpty",
  setup() {
    return {
      id: ++id
    };
  }
});
const _hoisted_1 = {
  viewBox: "0 0 79 86",
  version: "1.1",
  xmlns: "http://www.w3.org/2000/svg",
  "xmlns:xlink": "http://www.w3.org/1999/xlink"
};
const _hoisted_2 = ["id"];
const _hoisted_3 = /* @__PURE__ */ vue.createElementVNode("stop", {
  "stop-color": "var(--el-empty-fill-color-1)",
  offset: "0%"
}, null, -1);
const _hoisted_4 = /* @__PURE__ */ vue.createElementVNode("stop", {
  "stop-color": "var(--el-empty-fill-color-4)",
  offset: "100%"
}, null, -1);
const _hoisted_5 = [
  _hoisted_3,
  _hoisted_4
];
const _hoisted_6 = ["id"];
const _hoisted_7 = /* @__PURE__ */ vue.createElementVNode("stop", {
  "stop-color": "var(--el-empty-fill-color-1)",
  offset: "0%"
}, null, -1);
const _hoisted_8 = /* @__PURE__ */ vue.createElementVNode("stop", {
  "stop-color": "var(--el-empty-fill-color-6)",
  offset: "100%"
}, null, -1);
const _hoisted_9 = [
  _hoisted_7,
  _hoisted_8
];
const _hoisted_10 = ["id"];
const _hoisted_11 = {
  id: "Illustrations",
  stroke: "none",
  "stroke-width": "1",
  fill: "none",
  "fill-rule": "evenodd"
};
const _hoisted_12 = {
  id: "B-type",
  transform: "translate(-1268.000000, -535.000000)"
};
const _hoisted_13 = {
  id: "Group-2",
  transform: "translate(1268.000000, 535.000000)"
};
const _hoisted_14 = /* @__PURE__ */ vue.createElementVNode("path", {
  id: "Oval-Copy-2",
  d: "M39.5,86 C61.3152476,86 79,83.9106622 79,81.3333333 C79,78.7560045 57.3152476,78 35.5,78 C13.6847524,78 0,78.7560045 0,81.3333333 C0,83.9106622 17.6847524,86 39.5,86 Z",
  fill: "var(--el-empty-fill-color-3)"
}, null, -1);
const _hoisted_15 = /* @__PURE__ */ vue.createElementVNode("polygon", {
  id: "Rectangle-Copy-14",
  fill: "var(--el-empty-fill-color-7)",
  transform: "translate(27.500000, 51.500000) scale(1, -1) translate(-27.500000, -51.500000) ",
  points: "13 58 53 58 42 45 2 45"
}, null, -1);
const _hoisted_16 = {
  id: "Group-Copy",
  transform: "translate(34.500000, 31.500000) scale(-1, 1) rotate(-25.000000) translate(-34.500000, -31.500000) translate(7.000000, 10.000000)"
};
const _hoisted_17 = /* @__PURE__ */ vue.createElementVNode("polygon", {
  id: "Rectangle-Copy-10",
  fill: "var(--el-empty-fill-color-7)",
  transform: "translate(11.500000, 5.000000) scale(1, -1) translate(-11.500000, -5.000000) ",
  points: "2.84078316e-14 3 18 3 23 7 5 7"
}, null, -1);
const _hoisted_18 = /* @__PURE__ */ vue.createElementVNode("polygon", {
  id: "Rectangle-Copy-11",
  fill: "var(--el-empty-fill-color-5)",
  points: "-3.69149156e-15 7 38 7 38 43 -3.69149156e-15 43"
}, null, -1);
const _hoisted_19 = ["fill"];
const _hoisted_20 = /* @__PURE__ */ vue.createElementVNode("polygon", {
  id: "Rectangle-Copy-13",
  fill: "var(--el-empty-fill-color-2)",
  transform: "translate(39.500000, 3.500000) scale(-1, 1) translate(-39.500000, -3.500000) ",
  points: "24 7 41 7 55 -3.63806207e-12 38 -3.63806207e-12"
}, null, -1);
const _hoisted_21 = ["fill"];
const _hoisted_22 = {
  id: "Rectangle-Copy-17",
  transform: "translate(53.000000, 45.000000)"
};
const _hoisted_23 = ["id"];
const _hoisted_24 = ["xlink:href"];
const _hoisted_25 = ["xlink:href"];
const _hoisted_26 = ["mask"];
const _hoisted_27 = /* @__PURE__ */ vue.createElementVNode("polygon", {
  id: "Rectangle-Copy-18",
  fill: "var(--el-empty-fill-color-2)",
  transform: "translate(66.000000, 51.500000) scale(-1, 1) translate(-66.000000, -51.500000) ",
  points: "62 45 79 45 70 58 53 58"
}, null, -1);
function _sfc_render(_ctx, _cache, $props, $setup, $data, $options) {
  return vue.openBlock(), vue.createElementBlock("svg", _hoisted_1, [
    vue.createElementVNode("defs", null, [
      vue.createElementVNode("linearGradient", {
        id: `linearGradient-1-${_ctx.id}`,
        x1: "38.8503086%",
        y1: "0%",
        x2: "61.1496914%",
        y2: "100%"
      }, _hoisted_5, 8, _hoisted_2),
      vue.createElementVNode("linearGradient", {
        id: `linearGradient-2-${_ctx.id}`,
        x1: "0%",
        y1: "9.5%",
        x2: "100%",
        y2: "90.5%"
      }, _hoisted_9, 8, _hoisted_6),
      vue.createElementVNode("rect", {
        id: `path-3-${_ctx.id}`,
        x: "0",
        y: "0",
        width: "17",
        height: "36"
      }, null, 8, _hoisted_10)
    ]),
    vue.createElementVNode("g", _hoisted_11, [
      vue.createElementVNode("g", _hoisted_12, [
        vue.createElementVNode("g", _hoisted_13, [
          _hoisted_14,
          _hoisted_15,
          vue.createElementVNode("g", _hoisted_16, [
            _hoisted_17,
            _hoisted_18,
            vue.createElementVNode("rect", {
              id: "Rectangle-Copy-12",
              fill: `url(#linearGradient-1-${_ctx.id})`,
              transform: "translate(46.500000, 25.000000) scale(-1, 1) translate(-46.500000, -25.000000) ",
              x: "38",
              y: "7",
              width: "17",
              height: "36"
            }, null, 8, _hoisted_19),
            _hoisted_20
          ]),
          vue.createElementVNode("rect", {
            id: "Rectangle-Copy-15",
            fill: `url(#linearGradient-2-${_ctx.id})`,
            x: "13",
            y: "45",
            width: "40",
            height: "36"
          }, null, 8, _hoisted_21),
          vue.createElementVNode("g", _hoisted_22, [
            vue.createElementVNode("mask", {
              id: `mask-4-${_ctx.id}`,
              fill: "var(--el-empty-fill-color-0)"
            }, [
              vue.createElementVNode("use", {
                "xlink:href": `#path-3-${_ctx.id}`
              }, null, 8, _hoisted_24)
            ], 8, _hoisted_23),
            vue.createElementVNode("use", {
              id: "Mask",
              fill: "var(--el-empty-fill-color-8)",
              transform: "translate(8.500000, 18.000000) scale(-1, 1) translate(-8.500000, -18.000000) ",
              "xlink:href": `#path-3-${_ctx.id}`
            }, null, 8, _hoisted_25),
            vue.createElementVNode("polygon", {
              id: "Rectangle-Copy",
              fill: "var(--el-empty-fill-color-9)",
              mask: `url(#mask-4-${_ctx.id})`,
              transform: "translate(12.000000, 9.000000) scale(-1, 1) translate(-12.000000, -9.000000) ",
              points: "7 0 24 0 20 18 -1.70530257e-13 16"
            }, null, 8, _hoisted_26)
          ]),
          _hoisted_27
        ])
      ])
    ])
  ]);
}
var ImgEmpty = /* @__PURE__ */ pluginVue_exportHelper["default"](_sfc_main, [["render", _sfc_render]]);

exports["default"] = ImgEmpty;
//# sourceMappingURL=img-empty.js.map

==> element-plus-2.1.10.jar: META-INF/resources/webjars/element-plus/2.1.10/lib/components/empty/src/img-empty.js <==
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vue = require('vue');
var pluginVue_exportHelper = require('../../../_virtual/plugin-vue_export-helper.js');

let id = 0;
const _sfc_main = vue.defineComponent({
  name: "ImgEmpty",
  setup() {
    return {
      id: ++id
    };
  }
});
const _hoisted_1 = {
  viewBox: "0 0 79 86",
  version: "1.1",
  xmlns: "http://www.w3.org/2000/svg",
  "xmlns:xlink": "http://www.w3.org/1999/xlink"
};
const _hoisted_2 = ["id"];
const _hoisted_3 = /* @__PURE__ */ vue.createElementVNode("stop", {
  "stop-color": "var(--el-empty-fill-color-1)",
  offset: "0%"
}, null, -1);
const _hoisted_4 = /* @__PURE__ */ vue.createElementVNode("stop", {
  "stop-color": "var(--el-empty-fill-color-4)",
  offset: "100%"
}, null, -1);
const _hoisted_5 = [
  _hoisted_3,
  _hoisted_4
];
const _hoisted_6 = ["id"];
const _hoisted_7 = /* @__PURE__ */ vue.createElementVNode("stop", {
  "stop-color": "var(--el-empty-fill-color-1)",
  offset: "0%"
}, null, -1);
const _hoisted_8 = /* @__PURE__ */ vue.createElementVNode("stop", {
  "stop-color": "var(--el-empty-fill-color-6)",
  offset: "100%"
}, null, -1);
const _hoisted_9 = [
  _hoisted_7,
  _hoisted_8
];
const _hoisted_10 = ["id"];
const _hoisted_11 = {
  id: "Illustrations",
  stroke: "none",
  "stroke-width": "1",
  fill: "none",
  "fill-rule": "evenodd"
};
const _hoisted_12 = {
  id: "B-type",
  transform: "translate(-1268.000000, -535.000000)"
};
const _hoisted_13 = {
  id: "Group-2",
  transform: "translate(1268.000000, 535.000000)"
};
const _hoisted_14 = /* @__PURE__ */ vue.createElementVNode("path", {
  id: "Oval-Copy-2",
  d: "M39.5,86 C61.3152476,86 79,83.9106622 79,81.3333333 C79,78.7560045 57.3152476,78 35.5,78 C13.6847524,78 0,78.7560045 0,81.3333333 C0,83.9106622 17.6847524,86 39.5,86 Z",
  fill: "var(--el-empty-fill-color-3)"
}, null, -1);
const _hoisted_15 = /* @__PURE__ */ vue.createElementVNode("polygon", {
  id: "Rectangle-Copy-14",
  fill: "var(--el-empty-fill-color-7)",
  transform: "translate(27.500000, 51.500000) scale(1, -1) translate(-27.500000, -51.500000) ",
  points: "13 58 53 58 42 45 2 45"
}, null, -1);
const _hoisted_16 = {
  id: "Group-Copy",
  transform: "translate(34.500000, 31.500000) scale(-1, 1) rotate(-25.000000) translate(-34.500000, -31.500000) translate(7.000000, 10.000000)"
};
const _hoisted_17 = /* @__PURE__ */ vue.createElementVNode("polygon", {
  id: "Rectangle-Copy-10",
  fill: "var(--el-empty-fill-color-7)",
  transform: "translate(11.500000, 5.000000) scale(1, -1) translate(-11.500000, -5.000000) ",
  points: "2.84078316e-14 3 18 3 23 7 5 7"
}, null, -1);
const _hoisted_18 = /* @__PURE__ */ vue.createElementVNode("polygon", {
  id: "Rectangle-Copy-11",
  fill: "var(--el-empty-fill-color-5)",
  points: "-3.69149156e-15 7 38 7 38 43 -3.69149156e-15 43"
}, null, -1);
const _hoisted_19 = ["fill"];
const _hoisted_20 = /* @__PURE__ */ vue.createElementVNode("polygon", {
  id: "Rectangle-Copy-13",
  fill: "var(--el-empty-fill-color-2)",
  transform: "translate(39.500000, 3.500000) scale(-1, 1) translate(-39.500000, -3.500000) ",
  points: "24 7 41 7 55 -3.63806207e-12 38 -3.63806207e-12"
}, null, -1);
const _hoisted_21 = ["fill"];
const _hoisted_22 = {
  id: "Rectangle-Copy-17",
  transform: "translate(53.000000, 45.000000)"
};
const _hoisted_23 = ["xlink:href"];
const _hoisted_24 = ["mask"];
const _hoisted_25 = /* @__PURE__ */ vue.createElementVNode("polygon", {
  id: "Rectangle-Copy-18",
  fill: "var(--el-empty-fill-color-2)",
  transform: "translate(66.000000, 51.500000) scale(-1, 1) translate(-66.000000, -51.500000) ",
  points: "62 45 79 45 70 58 53 58"
}, null, -1);
function _sfc_render(_ctx, _cache, $props, $setup, $data, $options) {
  return vue.openBlock(), vue.createElementBlock("svg", _hoisted_1, [
    vue.createElementVNode("defs", null, [
      vue.createElementVNode("linearGradient", {
        id: `linearGradient-1-${_ctx.id}`,
        x1: "38.8503086%",
        y1: "0%",
        x2: "61.1496914%",
        y2: "100%"
      }, _hoisted_5, 8, _hoisted_2),
      vue.createElementVNode("linearGradient", {
        id: `linearGradient-2-${_ctx.id}`,
        x1: "0%",
        y1: "9.5%",
        x2: "100%",
        y2: "90.5%"
      }, _hoisted_9, 8, _hoisted_6),
      vue.createElementVNode("rect", {
        id: `path-3-${_ctx.id}`,
        x: "0",
        y: "0",
        width: "17",
        height: "36"
      }, null, 8, _hoisted_10)
    ]),
    vue.createElementVNode("g", _hoisted_11, [
      vue.createElementVNode("g", _hoisted_12, [
        vue.createElementVNode("g", _hoisted_13, [
          _hoisted_14,
          _hoisted_15,
          vue.createElementVNode("g", _hoisted_16, [
            _hoisted_17,
            _hoisted_18,
            vue.createElementVNode("rect", {
              id: "Rectangle-Copy-12",
              fill: `url(#linearGradient-1-${_ctx.id})`,
              transform: "translate(46.500000, 25.000000) scale(-1, 1) translate(-46.500000, -25.000000) ",
              x: "38",
              y: "7",
              width: "17",
              height: "36"
            }, null, 8, _hoisted_19),
            _hoisted_20
          ]),
          vue.createElementVNode("rect", {
            id: "Rectangle-Copy-15",
            fill: `url(#linearGradient-2-${_ctx.id})`,
            x: "13",
            y: "45",
            width: "40",
            height: "36"
          }, null, 8, _hoisted_21),
          vue.createElementVNode("g", _hoisted_22, [
            vue.createElementVNode("use", {
              id: "Mask",
              fill: "var(--el-empty-fill-color-8)",
              transform: "translate(8.500000, 18.000000) scale(-1, 1) translate(-8.500000, -18.000000) ",
              "xlink:href": `#path-3-${_ctx.id}`
            }, null, 8, _hoisted_23),
            vue.createElementVNode("polygon", {
              id: "Rectangle-Copy",
              fill: "var(--el-empty-fill-color-9)",
              mask: `url(#mask-4-${_ctx.id})`,
              transform: "translate(12.000000, 9.000000) scale(-1, 1) translate(-12.000000, -9.000000) ",
              points: "7 0 24 0 20 18 7 16.5"
            }, null, 8, _hoisted_24)
          ]),
          _hoisted_25
        ])
      ])
    ])
  ]);
}
var ImgEmpty = /* @__PURE__ */ pluginVue_exportHelper["default"](_sfc_main, [["render", _sfc_render], ["__file", "/home/runner/work/element-plus/element-plus/packages/components/empty/src/img-empty.vue"]]);

exports["default"] = ImgEmpty;
//# sourceMappingURL=img-empty.js.map
